==> qiho-center-api-2.7.24-hrd-20201211.063546-2-sources.jar: com/qiho/center/api/dto/StrategyRuleDto.java <==
package com.qiho.center.api.dto;

/**
 * Created by danke on 2017/6/21.
 * 策略规则类型的dto,主要用于保存策略的json属性
 */
public class StrategyRuleDto extends BaseDto{

    /**
     * 校验
     */
    private String fieldName;
    /**
     * 校验阈值
     */
    private String threshold;
    /**
     * 规则code
     */
    private String ruleName;

    /**
     * 规则是否应用部分商家
     */
    private Boolean partMerchant;

    /**
     * 规则类型code
     */
    private String strategyCode;


    /**
     * 策略商品类型 {@link com.qiho.center.api.enums.order.StrategyItemUserTypeEnum}
     */
    private Integer itemUseType;

    private Long strategyId;

    /**
     * 是否忽略该条规则
     */
    private Boolean isIgnore;

    public Boolean getIgnore() {
        return isIgnore;
    }

    public void setIgnore(Boolean ignore) {
        isIgnore = ignore;
    }

    public Long getStrategyId() {
        return strategyId;
    }

    public void setStrategyId(Long strategyId) {
        this.strategyId = strategyId;
    }

    public Integer getItemUseType() {
        return itemUseType;
    }

    public void setItemUseType(Integer itemUseType) {
        this.itemUseType = itemUseType;
    }

    public String getFieldName() {
        return fieldName;
    }

    public void setFieldName(String fieldName) {
        this.fieldName = fieldName;
    }

    public String getThreshold() {
        return threshold;
    }

    public void setThreshold(String threshold) {
        this.threshold = threshold;
    }

    public String getRuleName() {
        return ruleName;
    }

    public void setRuleName(String ruleName) {
        this.ruleName = ruleName;
    }

    public Boolean getPartMerchant() {
        return partMerchant;
    }

    public void setPartMerchant(Boolean partMerchant) {
        this.partMerchant = partMerchant;
    }

    public String getStrategyCode() {
        return strategyCode;
    }

    public void setStrategyCode(String strategyCode) {
        this.strategyCode = strategyCode;
    }

    public String getRuleKey() {
        return getFieldName() + "#" + getStrategyCode();
    }
}

==> qiho-center-api-2.7.25-hrd-20201224.085106-20-sources.jar: com/qiho/center/api/dto/StrategyRuleDto.java <==
package com.qiho.center.api.dto;

/**
 * Created by danke on 2017/6/21.
 * 策略规则类型的dto,主要用于保存策略的json属性
 */
public class StrategyRuleDto extends BaseDto{

    /**
     * 校验
     */
    private String fieldName;
    /**
     * 校验阈值
     */
    private String threshold;
    /**
     * 规则code
     */
    private String ruleName;

    /**
     * 规则是否应用部分商家
     */
    private Boolean partMerchant;

    /**
     * 规则类型code
     */
    private String strategyCode;


    /**
     * 策略商品类型 {@link com.qiho.center.api.enums.order.StrategyItemUserTypeEnum}
     */
    private Integer itemUseType;

    private Long strategyId;

    /**
     * 是否忽略该条规则
     */
    private Boolean isIgnore;

    public Boolean getIgnore() {
        return isIgnore;
    }

    public void setIgnore(Boolean ignore) {
        isIgnore = ignore;
    }

    public Long getStrategyId() {
        return strategyId;
    }

    public void setStrategyId(Long strategyId) {
        this.strategyId = strategyId;
    }

    public Integer getItemUseType() {
        return itemUseType;
    }

    public void setItemUseType(Integer itemUseType) {
        this.itemUseType = itemUseType;
    }

    public String getFieldName() {
        return fieldName;
    }

    public void setFieldName(String fieldName) {
        this.fieldName = fieldName;
    }

    public String getThreshold() {
        return threshold;
    }

    public void setThreshold(String threshold) {
        this.threshold = threshold;
    }

    public String getRuleName() {
        return ruleName;
    }

    public void setRuleName(String ruleName) {
        this.ruleName = ruleName;
    }

    public Boolean getPartMerchant() {
        return partMerchant;
    }

    public void setPartMerchant(Boolean partMerchant) {
        this.partMerchant = partMerchant;
    }

    public String getStrategyCode() {
        return strategyCode;
    }

    public void setStrategyCode(String strategyCode) {
        this.strategyCode = strategyCode;
    }

    public String getRuleKey() {
        return getFieldName() + "#" + getStrategyCode() + "#" + getRuleName();
    }
}
